@@ -8,13 +8,15 @@
 namespace rime {
 
 bool LegacyDictionaryConfigPlugin::ReviewCompileOutput(
-    ConfigCompiler* compiler, an<ConfigResource> resource) {
+    ConfigCompiler* compiler,
+    an<ConfigResource> resource) {
   // TODO: unimplemented
   return true;
 }
 
 bool LegacyDictionaryConfigPlugin::ReviewLinkOutput(
-    ConfigCompiler* compiler, an<ConfigResource> resource) {
+    ConfigCompiler* compiler,
+    an<ConfigResource> resource) {
   // TODO: unimplemented
   return true;
 }
